[interchange-cvs] interchange - jon modified 5 files

interchange-cvs at icdevgroup.org interchange-cvs at icdevgroup.org
Fri Aug 1 12:05:00 EDT 2003


User:      jon
Date:      2003-08-01 15:05:54 GMT
Modified:  .        test.pl
Modified:  dist/lib/UI/pages/admin transfer_catalog.html
Modified:  lib/Vend MakeCat.pm
Modified:  scripts  compile_link.PL makecat.PL
Log:
Use 127.0.0.1 instead of localhost for default INET host values to avoid
DNS lookup, as per bug #516.

Revision  Changes    Path
2.3       +1 -1      interchange/test.pl


rev 2.3, prev_rev 2.2
Index: test.pl
===================================================================
RCS file: /var/cvs/interchange/test.pl,v
retrieving revision 2.2
retrieving revision 2.3
diff -u -u -r2.2 -r2.3
--- test.pl	26 Nov 2002 15:21:56 -0000	2.2
+++ test.pl	1 Aug 2003 15:05:54 -0000	2.3
@@ -108,7 +108,7 @@
 $testnum++;
 
 use Socket;
-my $LINK_HOST    = 'localhost';
+my $LINK_HOST    = '127.0.0.1';
 my $LINK_PORT    = $ENV{MINIVEND_PORT};
 my $LINK_TIMEOUT = 15;
 my $ERROR_ACTION = "-none";



1.3       +2 -2      interchange/dist/lib/UI/pages/admin/transfer_catalog.html


rev 1.3, prev_rev 1.2
Index: transfer_catalog.html
===================================================================
RCS file: /var/cvs/interchange/dist/lib/UI/pages/admin/transfer_catalog.html,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -u -r1.2 -r1.3
--- transfer_catalog.html	10 Apr 2003 18:39:51 -0000	1.2
+++ transfer_catalog.html	1 Aug 2003 15:05:54 -0000	1.3
@@ -128,7 +128,7 @@
 			name=LINKHOST
 			cgi-default=1
 			type=text_20
-			] Link host if INET mode (default is localhost)
+			] Link host if INET mode (default is 127.0.0.1)
 		<br>
 		[display
 			name=LINKPORT
@@ -183,4 +183,4 @@
 <!-- ----- END REAL STUFF ----- -->
 
 @_UI_STD_FOOTER_@
-<!-- page: @@MV_PAGE@@  version: $Revision: 1.2 $ -->
+<!-- page: @@MV_PAGE@@  version: $Revision: 1.3 $ -->



2.12      +6 -6      interchange/lib/Vend/MakeCat.pm


rev 2.12, prev_rev 2.11
Index: compile_link.PL
===================================================================
RCS file: /var/cvs/interchange/scripts/compile_link.PL,v
retrieving revision 2.4
retrieving revision 2.5
diff -u -u -r2.4 -r2.5
--- compile_link.PL	18 Jun 2003 17:34:47 -0000	2.4
+++ compile_link.PL	1 Aug 2003 15:05:54 -0000	2.5
@@ -3,7 +3,7 @@
 #
 # Interchange link program configurator
 #
-# $Id: compile_link.PL,v 2.4 2003/06/18 17:34:47 jon Exp $
+# $Id: compile_link.PL,v 2.5 2003/08/01 15:05:54 jon Exp $
 #
 # Copyright (C) 2002-2003 Interchange Development Group
 # Copyright (C) 1996-2002 Red Hat, Inc.
@@ -39,7 +39,7 @@
 
 BEGIN {
 	$::Self = {
-		LINK_HOST      => 'localhost',
+		LINK_HOST      => '127.0.0.1',
 		LINK_PORT      => 7786,
 		LINK_TIMEOUT   => 30,
 		LINK_FILE      => '/usr/local/interchange/etc/socket',



2.22      +3 -3      interchange/scripts/makecat.PL


rev 2.22, prev_rev 2.21
Index: makecat.PL
===================================================================
RCS file: /var/cvs/interchange/scripts/makecat.PL,v
retrieving revision 2.21
retrieving revision 2.22
diff -u -u -r2.21 -r2.22
--- makecat.PL	18 Jun 2003 17:34:47 -0000	2.21
+++ makecat.PL	1 Aug 2003 15:05:54 -0000	2.22
@@ -3,7 +3,7 @@
 #
 # Interchange catalog configurator
 #
-# $Id: makecat.PL,v 2.21 2003/06/18 17:34:47 jon Exp $
+# $Id: makecat.PL,v 2.22 2003/08/01 15:05:54 jon Exp $
 #
 # Copyright (C) 2002-2003 Interchange Development Group
 # Copyright (C) 1996-2002 Red Hat, Inc.
@@ -1378,7 +1378,7 @@
 		}
 
 		sethistory(grep !$seen{$_}++, @hosts);
-		$default = $defhost || $Conf{linkhost} || 'localhost';
+		$default = $defhost || $Conf{linkhost} || '127.0.0.1';
 		while(! $lh) {
 			$lh = prompt("Link host? ", $default);
 			redo INETASK if $lh eq '@';
@@ -2299,7 +2299,7 @@
 
 =head1 VERSION
 
-# $Id: makecat.PL,v 2.21 2003/06/18 17:34:47 jon Exp $
+# $Id: makecat.PL,v 2.22 2003/08/01 15:05:54 jon Exp $
 
 =head1 INTRODUCTION
 







More information about the interchange-cvs mailing list
Index: MakeCat.pm
===================================================================
RCS file: /var/cvs/interchange/lib/Vend/MakeCat.pm,v
retrieving revision 2.11
retrieving revision 2.12
diff -u -u -r2.11 -r2.12
--- MakeCat.pm	18 Jun 2003 17:34:44 -0000	2.11
+++ MakeCat.pm	1 Aug 2003 15:05:54 -0000	2.12
@@ -1,6 +1,6 @@
 # Vend::MakeCat - Routines for Interchange catalog configurator
 #
-# $Id: MakeCat.pm,v 2.11 2003/06/18 17:34:44 jon Exp $
+# $Id: MakeCat.pm,v 2.12 2003/08/01 15:05:54 jon Exp $
 #
 # Copyright (C) 2002-2003 Interchange Development Group
 # Copyright (C) 1996-2002 Red Hat, Inc.
@@ -111,7 +111,7 @@
 	%Window
 /;
 
-$VERSION = substr(q$Revision: 2.11 $, 10);
+$VERSION = substr(q$Revision: 2.12 $, 10);
 
 $Force = 0;
 $History = 0;
@@ -343,9 +343,9 @@
 # CGI will talk to.
 #
 # If Interchange is running on the same server as your web
 # server, this should be "localhost". If the web server is on a
 # different machine, it is the IP address of the machine
 # Interchange is running on.
 EOF
 
 	linkmode => <<EOF,
@@ -1514,7 +1514,7 @@
 	my $prog = "$Conf{relocate}$Conf{vendroot}/src/tlink";
 	my $the_one = sum_it($prog);
 	my $defport = '7786';
-	my $defhost = 'localhost';
+	my $defhost = '127.0.0.1';
 
 	my @poss = glob("$Conf{relocate}$Conf{vendroot}/src/tlink.*.*");
 	for (@poss) {
@@ -343,9 +343,9 @@
 #
 # If Interchange is running on the same server as your web
-# server, this should be "localhost". If the web server is on a
-# different machine, it is the IP address of the machine
-# Interchange is running on.
+# server, this should be "localhost" or "127.0.0.1". If the web
+# server is on a different machine, it is the IP address of the
+# machine Interchange is running on.
 EOF
 



2.5       +2 -2      interchange/scripts/compile_link.PL


rev 2.5, prev_rev 2.4